@@ -1,6 +1,6 @@
 from os import path
 
-VERSION = '0.1.0'
-PREFS_FILE = '~/.api-buddy.yml'
+VERSION = '0.4.0'
+PREFS_FILE = '~/.api-buddy.yaml'
 ROOT_DIR = path.dirname(path.dirname(path.dirname(__file__)))
 MAX_LINE_LENGTH = 50
